@@ -19,6 +19,7 @@ def safe_name(chord):
     # replace '/' with _on_
     return chord.translate({ord("#"): "_sharp_", ord("/"): "_on_"})
 
+
 def chunk(iterable, chunksize):
     """
     iterate over an iterable, returning chunks of size (length) chunksize.
@@ -32,10 +33,7 @@ def chunk(iterable, chunksize):
 
     """
     for i in range(0, len(iterable), chunksize):
-        yield(iterable[i:i+chunksize])
+        yield (iterable[i : i + chunksize])
 
 
-custom_filters = {
-    "safe_name": safe_name,
-    "chunk": chunk
-}
+custom_filters = {"safe_name": safe_name, "chunk": chunk}
